@@ -91,7 +91,7 @@ rc_return_t procPopulate(rc_proc_t *pRc)
                 scriptnAppend(pRc->m_pScriptfunc, sBuf, nRet);
             if (nRet == -1) /* Handle read errors */
                 RC_THROW(RC_ERR_IO);
-            scriptnAppend(pRc->m_pScriptfunc, "\n", sizeof("\n"));
+            scriptnAppend(pRc->m_pScriptfunc, "\n", strlen("\n"));
             close(nFdfunc); /* Close Func file handle */
         }
         else
@@ -133,7 +133,8 @@ rc_return_t procPopulate(rc_proc_t *pRc)
         catch(Except)
             rethrow;
 
-        /* Attach our rcfile in the list */
+        /* Replace rcfile in the list with combined sections */
+        rcfileDelete(pRc->m_pList->m_ppFilevec[nRcs]);
         pRc->m_pList->m_ppFilevec[nRcs] = pRcfile;
         pRcfile = NULL;
     }
@@ -156,6 +157,10 @@ rc_return_t procPopulate(rc_proc_t *pRc)
 *******************************************/
 rc_return_t procRun(rc_proc_t *pRc)
 {
+    /* FIXME mlelstv - mode switch should be an enum
+     *                 set to one of the four modes
+     *                 and be tested with a switch()
+     */
     if (configGetval(RC_EVL_VAL))       /* Evaluate */
         return(procEval(pRc));
     else if (configGetval(RC_EXC_VAL))  /* Execute */
